# Mesh

Mesh commands are used to mesh part instances and regions. Mesh commands are also used to assign element sizes, element types, and mesh control parameters.

## Classes

### Mesh features for Assembly

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshAssembly.MeshAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ElemType

```{eval-rst}
.. autoclass:: abaqus.Mesh.ElemType.ElemType
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshEdge

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshEdge.MeshEdge
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshEdgeArray

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshEdgeArray.MeshEdgeArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshElement

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshElement.MeshElement
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshElementArray

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshElementArray.MeshElementArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MesherOptions

```{eval-rst}
.. autoclass:: abaqus.Mesh.MesherOptions.MesherOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshFace

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshFace.MeshFace
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshFaceArray

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshFaceArray.MeshFaceArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshNode

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshNode.MeshNode
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshNodeArray

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshNodeArray.MeshNodeArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshPart

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshPart.MeshPart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MeshStats

```{eval-rst}
.. autoclass:: abaqus.Mesh.MeshStats.MeshStats
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
